@@ -15,35 +15,36 @@ lmestMc <- function(responsesFormula = NULL,
   id.which <- which(names(data) == index[1])
   tv.which <- which(names(data) == index[2])
 
-  if(length(id.which) == 0)
-  {
-    stop("the id column does not exist")
-  }
-
-  if(length(tv.which) == 0)
-  {
-    stop("the time column does not exist")
-  }
+  if(length(id.which) == 0) stop("the id column does not exist")
+  if(length(tv.which) == 0) stop("the time column does not exist")
 
   id <- data[,id.which]
   tv <- data[,tv.which]
 
-  if(is.character(id) | is.factor(id))
-  {
+  if(is.character(id) | is.factor(id)){
     warning("id column must be numeric. Coerced in numeric.", call. = FALSE)
     id <- as.numeric(id)
   }
 
-  if(is.character(tv) | is.factor(tv))
-  {
+  if(is.character(tv) | is.factor(tv)){
     warning("time column must be numeric. Coerced in numeric.", call. = FALSE)
     tv <- as.numeric(tv)
   }
+  
+  if(!is.null(responsesFormula)) if(length(responsesFormula)==3){
+    if(is.null(responsesFormula[[3]]))
+      responsesFormula[[3]]=1
+    else{
+      if(length(responsesFormula[[3]])>1){
+        for(j in 1:length(responsesFormula[[3]])) 
+          if(is.null(responsesFormula[[3]][[j]])) responsesFormula[[3]][[j]] = 1
+      }
+    }
+  }
 
   data.new <- data[,-c(id.which,tv.which), drop = FALSE]
 
-  if(is.null(responsesFormula))
-  {
+  if(is.null(responsesFormula)){
     Y <- data.new
     Xmanifest <- NULL
     Xinitial <- NULL
@@ -56,17 +57,12 @@ lmestMc <- function(responsesFormula = NULL,
     Xtrans <- NULL
   }
 
-
-  if(!is.null(responsesFormula) & !is.null(responsesFormula[[3]]))
-  {
-    temp <- getLatent(data = data.new,latent = responsesFormula, responses = responsesFormula)
+  if(!is.null(responsesFormula) & !is.null(responsesFormula[[3]])){
+    temp <- getLatent(data = data.new,latent = responsesFormula,responses = responsesFormula)
     Xinitial <- temp$Xinitial
     Xtrans <- temp$Xtrans
   }
 
-
-
-
   if(dim(Y)[2] > 1){
     warning("multivariate data are not allowed; only the first response variable is considered", call. = FALSE)
     Y <- Y[,1]
@@ -78,8 +74,7 @@ lmestMc <- function(responsesFormula = NULL,
   Xtrans <- tmp$Xtrans
   Y <- tmp$Y
 
-  if(is.null(weights))
-  {
+  if(is.null(weights)){
     freq = tmp$freq
   }else{
     freq = weights
@@ -90,32 +85,17 @@ lmestMc <- function(responsesFormula = NULL,
     cat("|------------------- WARNING -------------------|\n")
     cat("|The first response category must be coded as 0 |\n")
     cat("|-----------------------------------------------|\n")
-    for(i in 1:dim(Y)[3])
-    {
-      Y[,,i] <- Y[,,i]-min(Y[,,i],na.rm = TRUE)
-    }
-  }
-
-  if(any(is.na(Y)))
-  {
-    stop("Missing data in the dataset")
+    for(i in 1:dim(Y)[3]) Y[,,i] <- Y[,,i]-min(Y[,,i],na.rm = TRUE)
   }
 
+  if(any(is.na(Y))) stop("Missing data in the dataset")
   if(!is.null(Xinitial))
-  {
     if(any(is.na(Xinitial)))
-    {
       stop("missing data in the covariates affecting the initial probabilities are not allowed")
-    }
-  }
-
   if(!is.null(Xtrans))
-  {
     if(any(is.na(Xtrans)))
-    {
       stop("missing data in the covariates affecting the transition probabilities are not allowed")
-    }
-  }
+
   out <- switch(model,
                 "LMbasic" = mcbasic(S = Y[,,1], yv = freq, modBasic = modBasic, tol = tol, maxit = maxit, out_se = out_se),
                 "LMlatent" = mccov(S = Y[,,1],X1 = Xinitial, X2 = Xtrans, start = start,yv = freq,
